==> dpay_flutter-1.4.2.tar.gz: ios/Classes/Helper.swift <==
//
//  Helper.swift
//  dpay_flutter
//
//  Created by user170390 on 6/15/21.
//

import Foundation

func checkIfInstalled(customURL: String) -> Bool {
    if (UIApplication.shared.canOpenURL(URL(string: customURL)!)) {
        return true
    }
    return false
}

func addQueryParameterToCheckoutUrl(
    checkoutUrl: String,
    query: String,
    options: NSMutableDictionary,
    errorTag: String,
    key: String) throws -> String {
    
    if let object = options.object(forKey: key) as? NSObject,
       String(describing: object) != "" ,
       !object.isEqual(NSNull()) {
        
        var parameterString = query
        parameterString += String(describing: object)
        return parameterString
    } else {throw NSError(domain: errorTag + " must not be empty", code: 400)}
}

func addOptionalQueryParameterToCheckoutUrl(
    checkoutUrl: String,
    query: String,
    options: NSMutableDictionary,
    key: String) throws -> String {
    
    if let object = options.object(forKey: key) as? NSObject,
       String(describing: object) != "" ,
       !object.isEqual(NSNull()) {
        
        var parameterString = query
        parameterString += String(describing: object)
        return parameterString
    }
    return ""
}

extension UIApplication {
    
    class func topViewController(_ viewController: UIViewController? = UIApplication.shared.keyWindow?.rootViewController) -> UIViewController? {
        if let nav = viewController as? UINavigationController {
            return topViewController(nav.visibleViewController)
        }
        if let tab = viewController as? UITabBarController {
            if let selected = tab.selectedViewController {
                return topViewController(selected)
            }
        }
        if let presented = viewController?.presentedViewController {
            return topViewController(presented)
        }
        return viewController
    }
    
    class func topNavigationController(_ viewController: UIViewController? = UIApplication.shared.keyWindow?.rootViewController) -> UINavigationController? {
        
        if let nav = viewController as? UINavigationController {
            return nav
        }
        if let tab = viewController as? UITabBarController {
            if let selected = tab.selectedViewController {
                return selected.navigationController
            }
        }
        return viewController?.navigationController
    }
}

==> dpay_flutter-2.0.2.tar.gz: ios/Classes/Helper.swift <==
//
//  Helper.swift
//  dpay_flutter
//
//  Created by user170390 on 6/15/21.
//

import Foundation

/*
 function to get values from options dictionary
 params:
    options - dictionary with checkout options
    key - key of dicitionary to get value
 */
func getCheckoutOptions(
    options: NSMutableDictionary,
    key: String) -> String {
    
    if let object = options.object(forKey: key) as? NSObject,
       String(describing: object) != "" ,
       !object.isEqual(NSNull()) {
        
        return String(describing: object)
    }
    return ""
}

//extension to add additional functions to the UIApplication class
extension UIApplication {
    
    //return the top most view controller in the stack, else, return root view controller
    class func topViewController(_ viewController: UIViewController? = UIApplication.shared.keyWindow?.rootViewController) -> UIViewController? {
        if let nav = viewController as? UINavigationController {
            return topViewController(nav.visibleViewController)
        }
        if let tab = viewController as? UITabBarController {
            if let selected = tab.selectedViewController {
                return topViewController(selected)
            }
        }
        if let presented = viewController?.presentedViewController {
            return topViewController(presented)
        }
        return viewController
    }
    
    //return the top navigation controller in the stack
    class func topNavigationController(_ viewController: UIViewController? = UIApplication.shared.keyWindow?.rootViewController) -> UINavigationController? {
        
        if let nav = viewController as? UINavigationController {
            return nav
        }
        if let tab = viewController as? UITabBarController {
            if let selected = tab.selectedViewController {
                return selected.navigationController
            }
        }
        return viewController?.navigationController
    }
}
